summaryrefslogtreecommitdiffstats
path: root/knewstuff/knewstuffgeneric.h
diff options
context:
space:
mode:
Diffstat (limited to 'knewstuff/knewstuffgeneric.h')
-rw-r--r--knewstuff/knewstuffgeneric.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/knewstuff/knewstuffgeneric.h b/knewstuff/knewstuffgeneric.h
index 053f83a05..36feb1a77 100644
--- a/knewstuff/knewstuffgeneric.h
+++ b/knewstuff/knewstuffgeneric.h
@@ -26,12 +26,12 @@
class TDEConfig;
/**
* @short Basic KNewStuff class with predefined actions.
*
* This class is used for data uploads and installation.
* \code
* TQString payload, preview;
- * KNewStuffGeneric *ns = new KNewStuffGeneric("kamikaze/level", this);
+ * TDENewStuffGeneric *ns = new TDENewStuffGeneric("kamikaze/level", this);
* ns->upload(payload, preview);
* \endcode
*
@@ -39,7 +39,7 @@ class TDEConfig;
* \par Maintainer:
* Josef Spillner (spillner@kde.org)
*/
-class KDE_EXPORT KNewStuffGeneric : public KNewStuff
+class KDE_EXPORT TDENewStuffGeneric : public TDENewStuff
{
public:
/**
@@ -48,8 +48,8 @@ class KDE_EXPORT KNewStuffGeneric : public KNewStuff
@param type a Hotstuff data type such as "korganizer/calendar"
@param parent the parent window.
*/
- KNewStuffGeneric( const TQString &type, TQWidget *parent = 0 );
- ~KNewStuffGeneric();
+ TDENewStuffGeneric( const TQString &type, TQWidget *parent = 0 );
+ ~TDENewStuffGeneric();
/**
Installs a downloaded file according to the application's configuration.
@@ -61,7 +61,7 @@ class KDE_EXPORT KNewStuffGeneric : public KNewStuff
/**
Creates a file suitable for upload.
- Note that this method always fails, since using KNewStuffGeneric
+ Note that this method always fails, since using TDENewStuffGeneric
means that the provided file must already be in a usable format.
@param fileName the name of the file to upload after its creation
@@ -26,12 +26,12 @@
class TDEConfig;
/**
- * @short Basic KNewStuff class with predefined actions.
+ * @short Basic TDENewStuff class with predefined actions.
*
* This class is used for data uploads and installation.